==> plasma-workspace-5.4.2.tar.xz: plasma-workspace-5.4.2/applets/systemtray/plugin/tasklistmodel.h <==
/*
 * QtQuick friendly list model of Tasks
 * Copyright (C) 2014  David Edmundson <david@davidedmundson.co.uk>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifndef TASKLISTMODEL_H
#define TASKLISTMODEL_H

#include <QAbstractListModel>

namespace SystemTray
{

class Task;

class TaskListModel : public QAbstractListModel
{
    Q_OBJECT
    Q_PROPERTY(int count READ count NOTIFY countChanged)

public:
    TaskListModel(QObject *parent = 0);
    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
    virtual int rowCount(const QModelIndex &parent= QModelIndex()) const;
    virtual QHash< int, QByteArray > roleNames() const;

    QList<Task*> tasks() const;

    void addTask(Task *task);
    void removeTask(Task *task);
    
    int count() const
    {
        return rowCount();
    }

Q_SIGNALS:
    void countChanged();

private:
    QList<Task*> m_tasks;
};
}

#endif // TASKLISTMODEL_H

==> plasma-workspace-5.6.2.tar.xz: plasma-workspace-5.6.2/applets/systemtray/plugin/tasklistmodel.h <==
/*
 * QtQuick friendly list model of Tasks
 * Copyright (C) 2014  David Edmundson <david@davidedmundson.co.uk>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifndef TASKLISTMODEL_H
#define TASKLISTMODEL_H

#include <QAbstractListModel>

namespace SystemTray
{

class Task;

class TaskListModel : public QAbstractListModel
{
    Q_OBJECT
    Q_PROPERTY(int count READ count NOTIFY countChanged)

public:
    TaskListModel(QObject *parent = 0);
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
    int rowCount(const QModelIndex &parent= QModelIndex()) const override;
    QHash< int, QByteArray > roleNames() const override;

    QList<Task*> tasks() const;

    void addTask(Task *task);
    void removeTask(Task *task);
    
    int count() const
    {
        return rowCount();
    }

Q_SIGNALS:
    void countChanged();

private:
    QList<Task*> m_tasks;
};
}

#endif // TASKLISTMODEL_H
